Exercise Questions
==================


Base class

    class BaseQuestion:


Perseus format (used by KA):

    class PerseusQuestion(BaseQuestion)


Currently supported internal formats:

    class SingleSelectQuestion(BaseQuestion)
    class MultipleSelectQuestion(BaseQuestion)
    class InputQuestion(BaseQuestion)

